<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Service\MapService;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;

class MapController extends TeknisaCrud{
    
    protected $mapService;
    protected $environment;
    protected $dataSourceGetLocations = 'getLocationForMap';
    protected $parameterBagColumns = array('IDATIVO', 'NRORG');
    const operatorLikeAll = 'LIKE_ALL';
    const operatorLikeI = 'LIKE_I';
    const operatorLike = 'LIKE';
    
    public function __construct(Manager $dataSourceManager, ParameterBag $parameterBag, $mapService, $environment) {
        $this->dataSourceManager = $dataSourceManager;
        $this->parameterBag = $parameterBag;
        $this->mapService = $mapService;
        $this->environment = $environment;
        parent::__construct($dataSourceManager, $parameterBag);
        
    }
    
    public function getLocationsForMap(DTO\Request\Filter $request, DTO\Response $response){
        try{
            $filters = $request->getFilterCriteria()->getConditions();
            
            $filters = $request->getParameters();
            
            // caso seja passado filtros, é setado na variável, casso contrário é setado um array vazio
            if(isset($filters['filter'])) {
                $filters = $filters['filter'];
            }else {
                $filters = array();
            }
            
            // define os parâmetros padrões
            $exists = false;
            $operexists = false;
            foreach($filters as $filtro) {
                if($filtro['name'] == 'IDATIVO') {
                    $exists = true;
                }
                if($filtro['name'] == 'CDOPERADOR') {
                    $operexists = true;
                }
            }
            
            if(!$exists) {
                $filters[] = array("name" => "IDATIVO", "operator" => "=", "value" => 'S');
            }
            if(!$operexists) {
                $filters[] = array("name" => "CDOPERADOR", "operator" => "=", "value" => $this->environment->getCdOperador());
            }
            $filters[] = array("name" => "NRORG", "operator" => "=", "value" => $this->environment->getNrorg());
            $filters[] = array("name" => "CRM_NRORGTRAB", "operator" => "=", "value" => $this->environment->getNrorg());
            
            $result = $this->mapService->getLocationsForMap(null, $filters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('locations', $result));
        }catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
        
    }
    
    public function geocode(DTO\Request $request, DTO\Response $response){
        try{
            $partners = $request->getDataSet();
            $partners = $partners->getRows();
            $error = $this->mapService->geocodePartners($partners);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('geocoded', (empty($error) ? 'done without errors' : $error)));
            
        }catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
        
    }
    
    public function atualizaLatLong(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $nrorg = $this->environment->getNrorg();
            foreach($request->getDataSet()->getRows() as $row) {
                $this->mapService->atualizaLatLong($row, $nrorg);
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }
    
}