<?php
namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;

class OrgOperFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection       = $entityManager->getConnection();
    }

    public function verifyMainOrg($nrorg) {
        try {
            $select = "SELECT * FROM CRM_ORGANIZACAO WHERE NRORG = :P_NRORG AND CRM_NRORGTRAB = :P_NRORG";
            
            $params = array(
                "P_NRORG" => $nrorg    
            );
            $std = $this->connection->prepare($select);
            $std->execute($params);
            $orgRaiz = $std->fetchAll();
            
            if(empty($orgRaiz)) {
                $select2 = "SELECT * FROM ORGANIZACAO WHERE NRORG = :P_NRORG";
                
                $params2 = array(
                    "P_NRORG" => $nrorg    
                );
                $std = $this->connection->prepare($select2);
                $std->execute($params2);
                $organizacao = $std->fetchAll();
                
                $insert = "INSERT INTO CRM_ORGANIZACAO VALUES(:P_NRORG, :P_CRM_NRORGTRAB, :P_NMORGTRAB, :P_DSORG, 'S', SYSDATE, SYSDATE, :P_NRORG, '1', :P_NRORG, '1')";
                $paramsInsert = array(
                    "P_NRORG"       => $nrorg,
                    "P_CRM_NRORGTRAB"   => $nrorg,
                    ":P_NMORGTRAB"  => $organizacao[0]['NMRAZSOCIALORG'],
                    "P_DSORG"       => $organizacao[0]['NMORGANIZACAO']
                );
                
                $std = $this->connection->prepare($insert);
                $std->execute($paramsInsert);
            }
        } catch(\Exception $e) {
            throw $e;
        };
    }
    
    public function deleteOperator($params, $swapOrg, $nmoperador, $cdoperadorInc, $params2) {
        try{
            if(count($this->searchRelatedOrgs($params['P_CDOPERADOR'], $params['P_NRORG'])) <= 1) {
                if($params['P_NRORG'] == $params['P_CRM_NRORGTRAB']) {
                    return 'error';
                }
            }

            $delete = "DELETE FROM 
                         CRM_ORGREL 
                       WHERE 
                         NRORG = :P_NRORG
                         AND CRM_NRORGTRAB = :P_CRM_NRORGTRAB
                         AND CDOPERADOR = :P_CDOPERADOR
                         AND IDATIVO = :P_IDATIVO";
                    
            $std = $this->connection->prepare($delete);
            $std->execute($params);
            
            
            $delete2 = "DELETE FROM 
                          CRM_STATUSPARC 
                        WHERE 
                          NRORG = :P_NRORG
                          AND CRM_NRORGTRAB = :P_CRM_NRORGTRAB
                          AND NRPARCNEGOCIO = :P_NRPARCNEGOCIO";
                    
            $std2 = $this->connection->prepare($delete2);
            $std2->execute($params2);
            
            if($swapOrg === 'true') {
                $update = "UPDATE OPERADOR SET CRM_NRORGTRAB = :P_NRORG WHERE CDOPERADOR = :P_CDOPERADOR AND NRORG = :P_NRORG";
                $params2 = array(
                    "P_NRORG" => $params['P_NRORG'],
                    "P_CDOPERADOR" => $params['P_CDOPERADOR']
                );
                
                $std = $this->connection->prepare($update);
                $std->execute($params2);
                
                if(empty($this->searchForOperatorOnMainOrg($params['P_CDOPERADOR'], $params['P_NRORG']))) {
                    $insert = "INSERT INTO 
                               CRM_ORGREL(CDOPERADOR, NRORG, CRM_NRORGTRAB, NMOPERADOR, IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU) 
                               VALUES(:P_CDOPERADOR, :P_NRORG, :P_NRORG, :P_NMOPERADOR, 'S', SYSDATE, SYSDATE, :P_NRORG, :P_CDOPERADORINC, :P_NRORG, :P_CDOPERADORINC)";
                               
                    $params3 = array(
                        "P_NRORG"           => $params['P_NRORG'],
                        "P_CDOPERADOR"      => $params['P_CDOPERADOR'],
                        "P_NMOPERADOR"      => $nmoperador,
                        "P_CDOPERADORINC"   => $cdoperadorInc
                    );
                    
                    $std = $this->connection->prepare($insert);
                    $std->execute($params3);
                }
            }
        }
        catch(\Exception $e) {
            throw $e;
        }; 
    }
    
    public function verifyExistenceOfOperators($params) {
        try {
            $select = "SELECT * FROM CRM_ORGREL WHERE NRORG = :P_NRORG AND CRM_NRORGTRAB = :P_CRM_NRORGTRAB";

            $std = $this->connection->prepare($select);
            $std->execute($params);
            return !empty($std->fetchAll());
        } catch(\Exception $e) {
            throw $e;
        };
    }
    
    public function verifyOrgTrab($params) {
        try {
            $select = "SELECT 
                          CASE 
                            WHEN NRORG = CRM_NRORGTRAB
                              THEN 'true'
                            ELSE 'false'
                          END AS SWAPORG
                        FROM
                          OPERADOR
                        WHERE
                          CDOPERADOR = :P_CDOPERADOR
                          AND NRORG = :P_NRORG";
            
            $params = array(
                "P_CDOPERADOR" => $params['P_CDOPERADOR'],
                "P_NRORG" => $params['P_NRORG']
            );
            
            $std = $this->connection->prepare($select);
            $std->execute($params);
            return $std->fetchAll()[0]['SWAPORG'];
        
        } catch(\Exception $e) {
            throw $e;
        };
    }
    
    public function alterarNrOrgTrab($params) {
        try{
            $update = "UPDATE OPERADOR SET CRM_NRORGTRAB = :P_CRM_NRORGTRAB WHERE CDOPERADOR = :P_CDOPERADOR AND NRORG = :P_NRORG";
            
            $std = $this->connection->prepare($update);
            $std->execute($params);
        } catch(\Exception $e) {
            throw $e;
        }; 
    }
    
    public function searchForOperatorOnMainOrg($cdoperador, $nrorg) {
        try {
            $select = "SELECT * FROM CRM_ORGREL WHERE NRORG = :P_NRORG AND CRM_NRORGTRAB = :P_NRORG AND CDOPERADOR = :P_CDOPERADOR";
            
            $params = array(
                "P_NRORG"      => $nrorg,
                "P_CDOPERADOR" => $cdoperador
            );
            
            $std = $this->connection->prepare($select);
            $std->execute($params);
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }; 
    }
    
    public function searchRelatedOrgs($cdoperador, $nrorg) {
        try {
            $select = "SELECT * FROM CRM_ORGREL WHERE NRORG = :P_NRORG AND CDOPERADOR = :P_CDOPERADOR";
            
            $params = array(
                "P_NRORG"      => $nrorg,
                "P_CDOPERADOR" => $cdoperador
            );
            
            $std = $this->connection->prepare($select);
            $std->execute($params);
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }; 
        
    }
    
    public function setOperStatus($params) {
        try {
            $insert = "INSERT INTO 
                       CRM_STATUSPARC(NRPARCNEGOCIO,
                                      NRPARCRESP,
                                      CDOPERRESP,
                                      STATUSPARC,
                                      NRORG,
                                      CRM_NRORGTRAB,
                                      IDATIVO,
                                      DTINCLUSAO,
                                      DTULTATU,
                                      NRORGINCLUSAO,
                                      CDOPERINCLUSAO,
                                      NRORGULTATU,
                                      CDOPERULTATU)
                       VALUES (:P_NRPARCNEGOCIO,
                               NULL,
                               NULL,
                               'OPERADOR',
                               :P_NRORG,
                               :P_CRM_NRORGTRAB,
                               'S',
                               SYSDATE,
                               SYSDATE,
                               :P_NRORG,
                               :P_CDOPERINCLUSAO,
                               :P_NRORG,
                               :P_CDOPERINCLUSAO)";
            
            $std = $this->connection->prepare($insert);
            $std->execute($params);
        } catch(\Exception $e) {
            throw $e;
        }; 
        
    }
}
?>