function crm00001002_Resultado_Evolucao_Perfil_Atividade(General, CRM_Utilities, ScreenService) {
    
    /**
     * Função para salvar um resultado de evolução
     * ao perfil de atividade em caso.
     * 
     * @param {object} widget widget ativa onde está
     * sendo realizado o cadastro do resultado da evolução.
    */
    this.saveNewActivityProfileEvolutionResult = function(widget){
        
        var currentRow = widget.currentRow;
        
        var activityProfileEvolutionResult= currentRow.RESULTADOS;
        var rows = [];
        
        activityProfileEvolutionResult.forEach(function(result, resultIndex){
            
            rows.push(this.setActivityProfileResultValuesInCurrentRow(widget, resultIndex));
                
        }.bind(this)); 
        
        General.callRestEngine("product#/crm_perfiresult_crm_resultevo/save", "DataSet", rows).then(function(response){
                
                ScreenService.closeSwipe().then(function(){
                    
                    widget.reload();
                    
                });
                
        }.bind(this));
    };
    
    /**
     * Função para pegar as informações do 
     * array de resultados na currentRow, e
     * tratá-las em uma cópia da currentRow para
     * realizar o save.
     * 
     * @param {object} widget widget ativa onde está
     * sendo realizado o cadastro do resultado da evolução.
     * 
     * @param {int} resultIndex index do resultado
     * no array de resultados presente na currentRow.
    */
    this.setActivityProfileResultValuesInCurrentRow = function(widget, resultIndex){
        
        var currentRow = angular.copy(widget.currentRow);
        var loggedOperatorInfos = CRM_Utilities.getLoggedOperatorInfos();
        
        currentRow.__is_new = true;
        currentRow.NRSEQPERFATIV = widget.getParent().currentRow.NRSEQPERFATIV;
        currentRow.NRSEQRESULEVOL = currentRow.RESULTADOS[resultIndex];
        currentRow.NRORG = loggedOperatorInfos.NRORG;
        
        return currentRow;
        
    };
    
    /**
     * Função para inserir um filtro na field
     * de resultados de evolução e logo em seguida,
     * atualiza a field.
     * 
     * @param {object} widget widget ativa no
     * modo edit, onde está sendo mostrado o campo
     * de resultados.
    */
    this.insertEvolutionResultFilter = function(widget){
        
        var resultField = widget.getField("RESULTADOS");
        var resultFieldFilter = resultField.dataSourceFilter;
        
        var nrseqperfativIndex = CRM_Utilities.getFilterPosition(resultFieldFilter, "P_NRSEQPERFATIV");
        
        resultFieldFilter[nrseqperfativIndex].value = widget.getParent().currentRow.NRSEQPERFATIV;
        
        resultField.reload();
    };
    
}

Configuration(function(ContextRegister) {
    ContextRegister.register('crm00001002_Resultado_Evolucao_Perfil_Atividade', crm00001002_Resultado_Evolucao_Perfil_Atividade);
});